---
title: ➡️  Autocompletion
eleventyNavigation:
  key: ➡️  Autocompletion
  parent: 💻 Command-line
---

borgmatic includes autocompletion scripts for various command-line shells to
support tab-completing command-line actions and flags. Depending on how you
installed borgmatic, this may be enabled by default. Here are the supported
shells and how to configure borgmatic autocompletion for each:

{{ collections.all | eleventyNavigation: "➡️  Autocompletion" | eleventyNavigationToHtml | replace: 'href="/reference/', 'href="/borgmatic/reference/' }}
